@@ -22,18 +22,18 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': 'x86_64-pc-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare',
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
- 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
-                            '-Werror=lto-type-mismatch -Werror=strict-aliasing '
-                            '-flto -ffat-lto-objects -flto -fuse-linker-plugin '
-                            '-ffat-lto-objects -g -std=c99 -Wextra '
-                            '-Wno-unused-result -Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic '
+                            '-Werror=odr -Werror=lto-type-mismatch '
+                            '-Werror=strict-aliasing -flto -ffat-lto-objects '
+                            '-fno-semantic-interposition -flto '
+                            '-fuse-linker-plugin -ffat-lto-objects -g -std=c99 '
+                            '-Wextra -Wno-unused-result -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
@@ -43,7 +43,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed '
                              '-Wl,-z,pack-relative-relocs -Werror=odr '
                              '-Werror=lto-type-mismatch '
-                             '-Werror=strict-aliasing -flto -flto '
+                             '-Werror=strict-aliasing -flto '
+                             '-fno-semantic-interposition -flto '
                              '-fuse-linker-plugin -ffat-lto-objects -g',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-linux-gnu' "
                 "'--host=x86_64-pc-linux-gnu' '--mandir=/usr/share/man' "
@@ -60,12 +61,17 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--without-ensurepip' '--without-lto' '--with-system-expat' "
                 "'--with-system-ffi' '--with-system-libmpdec' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--with-assertions' '--disable-optimizations' "
+                "'--without-assertions' '--enable-optimizations' "
                 "'--with-readline=readline' '--without-valgrind' '--with-lto' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' 'CFLAGS=' 'LDFLAGS=' "
-                "'CPPFLAGS= -I/usr/include/ncursesw' "
-                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config'",
+                "'CPPFLAGS= -I/usr/include/ncursesw' 'PROFILE_TASK=-m test "
+                '-j32 --pgo-extended -u-network --timeout 1200 -x test_gdb -x '
+                'test_dtrace -x test_asyncio -x test_concurrent_futures -x '
+                'test_httpservers -x test_logging -x test_multiprocessing_fork '
+                "-x test_socket -x test_xmlrpc -x test_tools' "
+                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' "
+                "'PKG_CONFIG_PATH=/usr/share/guile-data/3.0/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.10',
  'COREPYTHONPATH': '',
@@ -551,21 +557,21 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.10',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.10',
- 'INSTALL': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c',
- 'INSTALL_DATA': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install -c '
-                 '-m 644',
- 'INSTALL_PROGRAM': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
+            '-c',
+ 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
+                 '-c -m 644',
+ 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/usr/lib/portage/python3.13/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.818jrldh/bin/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.10.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'x86_64-pc-linux-gnu-g++ -shared',
  'LDFLAGS': '',
- 'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.10.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'x86_64-pc-linux-gnu-gcc -shared',
@@ -633,7 +639,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPENSSL_RPATH': '',
- 'OPT': '',
+ 'OPT': '-DNDEBUG',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -650,7 +656,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo --timeout=1200',
+ 'PROFILE_TASK': '-m test -j32 --pgo-extended -u-network --timeout 1200 -x '
+                 'test_gdb -x test_dtrace -x test_asyncio -x '
+                 'test_concurrent_futures -x test_httpservers -x test_logging '
+                 '-x test_multiprocessing_fork -x test_socket -x test_xmlrpc '
+                 '-x test_tools',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -667,61 +677,69 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -O2 -pipe '
-                             '-march=x86-64-v3 -Werror=odr '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
+                             '-pipe -march=x86-64 -mtune=generic -Werror=odr '
                              '-Werror=lto-type-mismatch '
                              '-Werror=strict-aliasing -flto -ffat-lto-objects '
-                             '-flto -fuse-linker-plugin -ffat-lto-objects -g '
+                             '-fno-semantic-interposition -flto '
+                             '-fuse-linker-plugin -ffat-lto-objects -g '
                              '-std=c99 -Wextra -Wno-unused-result '
                              '-Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-fvisibility=hidden -fprofile-use '
+                             '-fprofile-correction -I./Include/internal -I. '
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare',
- 'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64-v3 -Werror=odr '
+ 'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG',
+ 'PY_CFLAGS_NODIST': '-O2 -pipe -march=x86-64 -mtune=generic -Werror=odr '
                      '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
-                     '-ffat-lto-objects -flto -fuse-linker-plugin '
-                     '-ffat-lto-objects -g -std=c99 -Wextra -Wno-unused-result '
-                     '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wstrict-prototypes '
+                     '-ffat-lto-objects -fno-semantic-interposition -flto '
+                     '-fuse-linker-plugin -ffat-lto-objects -g -std=c99 '
+                     '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden  -I./Include/internal',
+                     '-fvisibility=hidden -fprofile-use -fprofile-correction '
+                     '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -O2 -pipe '
-                   '-march=x86-64-v3 -Werror=odr -Werror=lto-type-mismatch '
-                   '-Werror=strict-aliasing -flto -ffat-lto-objects -flto '
+ 'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe '
+                   '-march=x86-64 -mtune=generic -Werror=odr '
+                   '-Werror=lto-type-mismatch -Werror=strict-aliasing -flto '
+                   '-ffat-lto-objects -fno-semantic-interposition -flto '
                    '-fuse-linker-plugin -ffat-lto-objects -g -std=c99 -Wextra '
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
-                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
-                   '-I./Include/internal -I. -I./Include '
-                   '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
+                   '-Werror=implicit-function-declaration -fvisibility=hidden '
+                   '-fprofile-use -fprofile-correction -I./Include/internal '
+                   '-I. -I./Include -I/usr/include/ncursesw -fPIC '
+                   '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
                     '-Werror=odr -Werror=lto-type-mismatch '
-                    '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
-                    '-ffat-lto-objects -g',
+                    '-Werror=strict-aliasing -flto -fno-semantic-interposition '
+                    '-flto -fuse-linker-plugin -ffat-lto-objects -g',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
  'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs '
                       '-Werror=odr -Werror=lto-type-mismatch '
-                      '-Werror=strict-aliasing -flto -flto -fuse-linker-plugin '
+                      '-Werror=strict-aliasing -flto '
+                      '-fno-semantic-interposition -flto -fuse-linker-plugin '
                       '-ffat-lto-objects -g',
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -O2 -pipe '
-                        '-march=x86-64-v3 -Werror=odr '
+ 'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -pipe '
+                        '-march=x86-64 -mtune=generic -Werror=odr '
                         '-Werror=lto-type-mismatch -Werror=strict-aliasing '
-                        '-flto -ffat-lto-objects -flto -fuse-linker-plugin '
-                        '-ffat-lto-objects -g -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
-                        '-Wno-missing-field-initializers -Wstrict-prototypes '
+                        '-flto -ffat-lto-objects -fno-semantic-interposition '
+                        '-flto -fuse-linker-plugin -ffat-lto-objects -g '
+                        '-std=c99 -Wextra -Wno-unused-result '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-fvisibility=hidden -fprofile-use '
+                        '-fprofile-correction -I./Include/internal -I. '
                         '-I./Include -I/usr/include/ncursesw -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
